---
name: "🐞 Bug Report"
about: Create a report to help us improve
title: ''
labels: 'type:Bug'
assignees: ''

---

Found a bug? Please fill out the sections below. 👍

### Issue Summary

A summary of the issue.

### Steps to Reproduce

1. (for example) Start a new project with `scratchip create myproject`
2. Edit xxx as follows...
3. ...

### What is the current behavior?

### What is the expected behavior?

### What is your environment

<!-- (examples)
    - version: `0.2`
    - Python: 3.8.2
-->
